@@ -2,11 +2,11 @@
 **  Copyright (c) 2006-2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: config.c,v 1.8 2008/02/14 00:19:59 msk Exp $
+**  $Id: config.c,v 1.10 2008/06/06 19:40:27 msk Exp $
 */
 
 #ifndef lint
-static char config_c_id[] = "@(#)$Id: config.c,v 1.8 2008/02/14 00:19:59 msk Exp $";
+static char config_c_id[] = "@(#)$Id: config.c,v 1.10 2008/06/06 19:40:27 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -139,6 +139,7 @@ config_load_level(char *file, struct configdef *def,
 	while (fgets(buf, sizeof buf - 1, in) != NULL)
 	{
 		myline++;
+		str = NULL;
 
 		/* read a line; truncate at newline or "#" */
 		for (p = buf; *p != '\0'; p++)
@@ -175,7 +176,7 @@ config_load_level(char *file, struct configdef *def,
 						break;
 				}
 			}
-			else
+			else if (str == NULL)
 			{
 				char *q;
 
@@ -219,6 +220,8 @@ config_load_level(char *file, struct configdef *def,
 						err = 1;
 					}
 
+					str = p;
+
 					break;
 
 				  default:
@@ -308,7 +311,36 @@ config_load_level(char *file, struct configdef *def,
 
 	conf_error = CONF_SUCCESS;
 
-	return cur;
+	if (myline == 0)
+	{
+		cur = (struct config *) malloc(sizeof *cur);
+		if (cur != NULL)
+		{
+			cur->cfg_bool = FALSE;
+			cur->cfg_type = CONFIG_TYPE_STRING;
+			cur->cfg_int = 0;
+			cur->cfg_name = "";
+			cur->cfg_string = "";
+			cur->cfg_next = NULL;
+
+			return cur;
+		}
+		else
+		{
+			conf_error = CONF_NMEMORY;
+
+			if (line != NULL)
+				*line = myline;
+			if (outpath != NULL)
+				sm_strlcpy(outpath, file, outpathlen);
+
+			return NULL;
+		}
+	}
+	else
+	{
+		return cur;
+	}
 }
 
 /*
