@@ -2,11 +2,11 @@
 **  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-ar.c,v 1.24 2008/04/10 18:23:43 msk Exp $
+**  $Id: dkim-ar.c,v 1.25 2008/05/22 06:29:14 msk Exp $
 */
 
 #ifndef lint
-static char dkim_ar_c_id[] = "@(#)$Id: dkim-ar.c,v 1.24 2008/04/10 18:23:43 msk Exp $";
+static char dkim_ar_c_id[] = "@(#)$Id: dkim-ar.c,v 1.25 2008/05/22 06:29:14 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -19,6 +19,9 @@ static char dkim_ar_c_id[] = "@(#)$Id: dkim-ar.c,v 1.24 2008/04/10 18:23:43 msk
 # include <sysexits.h>
 #endif /* ARTEST */
 
+/* libsm includes */
+#include <sm/string.h>
+
 /* dkim-filter includes */
 #include "dkim-ar.h"
 
@@ -367,16 +370,13 @@ ares_xconvert(struct lookup *table, int code)
 int
 ares_parse(u_char *hdr, struct authres *ar)
 {
-	bool escaped;
 	bool quoted;
-	int paren;
 	int n;
 	int ntoks;
 	int c;
 	int r;
 	int state;
 	int prevstate;
-	u_char *p;
 	u_char tmp[DKIM_MAXHEADER + 2];
 	u_char *tokens[ARES_MAXTOKENS];
 
