@@ -2,14 +2,14 @@
 **  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-ar.h,v 1.11 2008/03/14 06:09:50 msk Exp $
+**  $Id: dkim-ar.h,v 1.12 2008/05/22 06:29:14 msk Exp $
 */
 
 #ifndef _DKIM_AR_H_
 #define _DKIM_AR_H_
 
 #ifndef lint
-static char dkim_ar_h_id[] = "@(#)$Id: dkim-ar.h,v 1.11 2008/03/14 06:09:50 msk Exp $";
+static char dkim_ar_h_id[] = "@(#)$Id: dkim-ar.h,v 1.12 2008/05/22 06:29:14 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -69,7 +69,7 @@ struct result
 	ares_method_t	result_method;
 	ares_result_t	result_result;
 	ares_ptype_t	result_ptype[MAXPROPS];
-	unsigned char	result_reason[MAXPROPS][MAXAVALUE + 1];
+	unsigned char	result_reason[MAXAVALUE + 1];
 	unsigned char	result_property[MAXPROPS][MAXAVALUE + 1];
 	unsigned char	result_value[MAXPROPS][MAXAVALUE + 1];
 };
