@@ -2,14 +2,14 @@
 **  Copyright (c) 2006-2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-config.h,v 1.53 2008/04/04 22:01:33 msk Exp $
+**  $Id: dkim-config.h,v 1.58 2008/05/23 00:08:51 msk Exp $
 */
 
 #ifndef _DKIM_CONFIG_H_
 #define _DKIM_CONFIG_H_
 
 #ifndef lint
-static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.53 2008/04/04 22:01:33 msk Exp $";
+static char dkim_config_h_id[] = "@(#)$Id: dkim-config.h,v 1.58 2008/05/23 00:08:51 msk Exp $";
 #endif /* !lint */
 
 struct configdef dkimf_config[] =
@@ -17,9 +17,9 @@ struct configdef dkimf_config[] =
 	{ "AllowSHA1Only",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AlwaysAddARHeader",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AlwaysSignHeaders",		CONFIG_TYPE_STRING,	FALSE },
-#ifdef _FFR_AUTHSERV_JOBID
+	{ "ASPDiscard",			CONFIG_TYPE_BOOLEAN,	FALSE },
+	{ "ASPNoSuchDomain",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AuthservIDWithJobID",	CONFIG_TYPE_BOOLEAN,	FALSE },
-#endif /* _FFR_AUTHSERV_JOBID */
 	{ "AutoRestart",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "AutoRestartCount",		CONFIG_TYPE_INTEGER,	FALSE },
 	{ "AutoRestartRate",		CONFIG_TYPE_STRING,	FALSE },
@@ -36,6 +36,7 @@ struct configdef dkimf_config[] =
 #endif /* _FFR_ZTAGS */
 	{ "DNSTimeout",			CONFIG_TYPE_INTEGER,	FALSE },
 	{ "Domain",			CONFIG_TYPE_STRING,	FALSE },
+	{ "DontSignMailTo",		CONFIG_TYPE_STRING,	FALSE },
 	{ "ExternalIgnoreList",		CONFIG_TYPE_STRING,	FALSE },
 	{ "FixCRLF",			CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "KeyFile",			CONFIG_TYPE_STRING,	FALSE },
@@ -50,6 +51,7 @@ struct configdef dkimf_config[] =
 	{ "Minimum",			CONFIG_TYPE_STRING,	FALSE },
 	{ "Mode",			CONFIG_TYPE_STRING,	FALSE },
 	{ "MTA",			CONFIG_TYPE_STRING,	FALSE },
+	{ "MustBeSigned",		CONFIG_TYPE_STRING,	FALSE },
 	{ "OmitHeaders",		CONFIG_TYPE_STRING,	FALSE },
 	{ "On-BadSignature",		CONFIG_TYPE_STRING,	FALSE },
 	{ "On-Default",			CONFIG_TYPE_STRING,	FALSE },
@@ -74,6 +76,7 @@ struct configdef dkimf_config[] =
 #ifdef _FFR_REPLACE_RULES
 	{ "ReplaceRules",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_REPLACE_RULES */
+	{ "ReportAddress",		CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_REQUIRED_HEADERS
 	{ "RequiredHeaders",		CONFIG_TYPE_BOOLEAN,	FALSE },
 #endif /* _FFR_REQUIRED_HEADERS */
@@ -81,6 +84,7 @@ struct configdef dkimf_config[] =
 #ifdef _FFR_SELECTOR_HEADER
 	{ "SelectorHeader",		CONFIG_TYPE_STRING,	FALSE },
 #endif /* _FFR_SELECTOR_HEADER */
+	{ "SendASPReports",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "SendReports",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "SignatureAlgorithm",		CONFIG_TYPE_STRING,	FALSE },
 	{ "SignatureTTL",		CONFIG_TYPE_INTEGER,	FALSE },
@@ -95,7 +99,6 @@ struct configdef dkimf_config[] =
 	{ "SyslogFacility",		CONFIG_TYPE_STRING,	FALSE },
 	{ "SyslogSuccess",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "UMask",			CONFIG_TYPE_INTEGER,	FALSE },
-	{ "UseASPDiscard",		CONFIG_TYPE_BOOLEAN,	FALSE },
 	{ "UserID",			CONFIG_TYPE_STRING,	FALSE },
 #ifdef _FFR_VBR
 	{ "VBR-Certifiers",		CONFIG_TYPE_STRING,	FALSE },
