@@ -2,18 +2,19 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-filter.h,v 1.173 2008/04/25 15:29:31 msk Exp $
+**  $Id: dkim-filter.h,v 1.182 2008/06/11 09:50:42 msk Exp $
 */
 
 #ifndef _DKIM_FILTER_H_
 #define _DKIM_FILTER_H_
 
 #ifndef lint
-static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.173 2008/04/25 15:29:31 msk Exp $";
+static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.182 2008/06/11 09:50:42 msk Exp $";
 #endif /* !lint */
 
 #define	DKIMF_PRODUCT	"Sendmail DKIM Filter"
-#define	DKIMF_VERSION	"2.5.5"
+#define	DKIMF_PRODUCTNS	"Sendmail-DKIM-Filter"
+#define	DKIMF_VERSION	"2.6.0"
 
 /* libsm */
 #include <sm/gen.h>
@@ -36,7 +37,7 @@ static char dkim_filter_h_id[] = "@(#)$Id: dkim-filter.h,v 1.173 2008/04/25 15:2
 #define	BUFRSZ		1024
 #define	CACHESTATSINT	300
 #define	CBINTERVAL	3
-#define CMDLINEOPTS	"a:Ab:c:C:d:DfF:hi:I:k:KlL:m:M:o:p:P:qrRs:S:t:T:u:U:vVWx:?"
+#define CMDLINEOPTS	"a:Ab:c:C:d:DfF:hi:I:k:KlL:m:M:no:p:P:qrRs:S:t:T:u:U:vVWx:?"
 #define	DEFMAXHDRSZ	65536
 #define	DEFTIMEOUT	5
 #define	HOSTUNKNOWN	"unknown-host"
