@@ -2,11 +2,11 @@
 **  Copyright (c) 2007, 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: dkim-testssp.c,v 1.6 2008/01/10 21:21:05 msk Exp $
+**  $Id: dkim-testssp.c,v 1.8 2008/03/17 16:41:08 msk Exp $
 */
 
 #ifndef lint
-static char dkim_testssp_c[] = "@(#)$Id: dkim-testssp.c,v 1.6 2008/01/10 21:21:05 msk Exp $";
+static char dkim_testssp_c[] = "@(#)$Id: dkim-testssp.c,v 1.8 2008/03/17 16:41:08 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -70,7 +70,6 @@ main(int argc, char **argv)
 	DKIM_STAT status;
 	int i;
 	dkim_policy_t pcode;
-	dkim_handling_t hcode;
 	int presult;
 	DKIM_LIB *lib;
 	char *p;
@@ -91,7 +90,7 @@ main(int argc, char **argv)
 	{
 		domain = argv[i];
 
-		status = dkim_test_ssp(lib, domain, &pcode, &hcode, &presult,
+		status = dkim_test_asp(lib, domain, &pcode, &presult,
 		                       err, sizeof err);
 
 		if (status != DKIM_STAT_OK)
@@ -101,10 +100,9 @@ main(int argc, char **argv)
 		else
 		{
 			fprintf(stdout,
-			        "%s: %s:\n\tpolicy is \"%s\"\n\thandling is \"%s\"\n\tpolicy code is \"%s\"\n",
+			        "%s: %s:\n\tpolicy is \"%s\"\n\tpolicy result code is \"%s\"\n",
 			        progname, domain,
 			        STRORNULL(dkim_getpolicystr(pcode)),
-			        STRORNULL(dkim_gethandlingstr(hcode)),
 			        STRORNULL(dkim_getpresultstr(presult)));
 		}
 	}
