@@ -2,11 +2,11 @@
 **  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: util.c,v 1.70 2008/04/17 17:08:19 msk Exp $
+**  $Id: util.c,v 1.73 2008/05/23 00:08:51 msk Exp $
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.70 2008/04/17 17:08:19 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.73 2008/05/23 00:08:51 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -82,10 +82,6 @@ static char *optlist[] =
 	"_FFR_ANTICIPATE_SENDMAIL_MUNGE",
 #endif /* _FFR_ANTICIPATE_SENDMAIL_MUNGE */
 
-#if _FFR_AUTHSERV_JOBID
-	"_FFR_AUTHSERV_JOBID",
-#endif /* _FFR_AUTHSERV_JOBID */
-
 #ifdef _FFR_BODYLENGTH_DB
 	"_FFR_BODYLENGTH_DB",
 #endif /* _FFR_BODYLENGTH_DB */
@@ -146,6 +142,9 @@ struct dkimf_dstring
 	char *			ds_buf;
 };
 
+/* base64 alphabet */
+static unsigned char alphabet[64] = "ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
+
 #ifdef _FFR_REPLACE_RULES
 /*
 **  DKIMF_ISBLANK -- return TRUE iff a string contains only whitespace
@@ -1409,3 +1408,163 @@ dkimf_socket_cleanup(char *sockspec)
 	close(s);
 	return EADDRINUSE;
 }
+
+/*
+**  DKIMF_MKREGEXP -- make a regexp string from a glob string
+**
+**  Parameters:
+**  	src -- source string
+**  	dst -- destination string
+**  	dstlen -- space available at "dest"
+**
+**  Return value:
+**  	TRUE iff "dest" was big enough (based on destlen)
+*/
+
+bool
+dkimf_mkregexp(char *src, char *dst, size_t dstlen)
+{
+	char *p;
+	char *q;
+	char *end;
+
+	assert(src != NULL);
+	assert(dst != NULL);
+
+	if (dstlen == 0)
+		return FALSE;
+
+	dst[0] = '^';
+
+	end = dst + dstlen;
+
+	for (p = src, q = dst + 1; *p != '\0' && q < end; p++)
+	{
+		switch (*p)
+		{
+		  case '*':
+			*q = '.';
+			q++;
+			*q = '*';
+			q++;
+			break;
+
+		  case '.':
+			*q = '\\';
+			q++;
+			*q = '.';
+			q++;
+			break;
+
+		  default:
+			*q = *p;
+			q++;
+			break;
+		}
+	}
+
+	*q++ = '$';
+
+	if (q >= end)
+		return FALSE;
+	else
+		return TRUE;
+}
+
+/*
+**  DKIMF_BASE64_ENCODE_FILE -- base64-encode a file
+**
+**  Parameters:
+**  	infd -- input file descriptor
+**  	out -- output stream
+**  	lm -- left margin
+** 	rm -- right margin
+**  	initial -- space consumed on the initial line
+**
+**  Return value:
+**  	None (yet).
+*/
+
+void
+dkimf_base64_encode_file(infd, out, lm, rm, initial)
+	int infd;
+	FILE *out;
+	int lm;
+	int rm;
+	int initial;
+{
+	int len;
+	int bits;
+	int c;
+	int d;
+	int char_count;
+	ssize_t rlen;
+	char buf[MAXBUFRSZ];
+
+	assert(infd >= 0);
+	assert(out != NULL);
+	assert(lm >= 0);
+	assert(rm >= 0);
+	assert(initial >= 0);
+
+	bits = 0;
+	char_count = 0;
+	len = initial;
+
+	(void) lseek(infd, 0, SEEK_SET);
+
+	for (;;)
+	{
+		rlen = read(infd, buf, sizeof buf);
+		if (rlen == -1)
+			break;
+
+		for (c = 0; c < rlen; c++)
+		{
+			bits += buf[c];
+			char_count++;
+			if (char_count == 3)
+			{
+				fputc(alphabet[bits >> 18], out);
+				fputc(alphabet[(bits >> 12) & 0x3f], out);
+				fputc(alphabet[(bits >> 6) & 0x3f], out);
+				fputc(alphabet[bits & 0x3f], out);
+				len += 4;
+				if (rm > 0 && lm > 0 && len >= rm - 4)
+				{
+					fputc('\n', out);
+					for (d = 0; d < lm; d++)
+						fputc(' ', out);
+					len = lm;
+				}
+				bits = 0;
+				char_count = 0;
+			}
+			else
+			{
+				bits <<= 8;
+			}
+		}
+
+		if (rlen < (ssize_t) sizeof buf)
+			break;
+	}
+
+	if (char_count != 0)
+	{
+		if (rm > 0 && lm > 0 && len >= rm - 4)
+		{
+			fputc('\n', out);
+			for (d = 0; d < lm; d++)
+				fputc(' ', out);
+		}
+		bits <<= 16 - (8 * char_count);
+		fputc(alphabet[bits >> 18], out);
+		fputc(alphabet[(bits >> 12) & 0x3f], out);
+		if (char_count == 1)
+			fputc('=', out);
+		else
+			fputc(alphabet[(bits >> 6) & 0x3f], out);
+		fputc('=', out);
+	}
+}
