@@ -2,14 +2,14 @@
 **  Copyright (c) 2004, 2005, 2007, 2008 Sendmail, Inc. and its suppliers.
 **	All rights reserved.
 **
-**  $Id: util.h,v 1.18 2008/02/17 21:18:45 msk Exp $
+**  $Id: util.h,v 1.20 2008/05/22 06:33:34 msk Exp $
 */
 
 #ifndef _UTIL_H_
 #define _UTIL_H_
 
 #ifndef lint
-static char util_h_id[] = "@(#)$Id: util.h,v 1.18 2008/02/17 21:18:45 msk Exp $";
+static char util_h_id[] = "@(#)$Id: util.h,v 1.20 2008/05/22 06:33:34 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -46,6 +46,7 @@ struct replace
 #endif /* _FFR_REPLACE_RULES */
 
 /* PROTOTYPES */
+extern void dkimf_base64_encode_file __P((int, FILE *, int, int, int));
 extern bool dkimf_checkhost __P((Peer, char *));
 extern bool dkimf_checkip __P((Peer, struct sockaddr *));
 #ifdef POPAUTH
@@ -64,6 +65,7 @@ extern bool dkimf_load_replist __P((FILE *, struct replace **));
 #endif /* _FFR_REPLACE_RULES */
 extern void dkimf_lowercase __P((u_char *));
 extern void dkimf_mkpath __P((char *, size_t, char *, char *));
+extern bool dkimf_mkregexp __P((char *, char *, size_t));
 extern void dkimf_optlist __P((FILE *));
 extern void dkimf_setmaxfd __P((void));
 extern int dkimf_socket_cleanup __P((char *));
