@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.45 2008/04/11 23:16:24 msk Exp $";
+static char dkim_canon_c_id[] = "@(#)$Id: dkim-canon.c,v 1.47 2008/05/08 00:13:45 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -727,10 +727,13 @@ dkim_canon_cleanup(DKIM *dkim)
 	while (cur != NULL)
 	{
 		next = cur->canon_next;
-		dkim_mfree(dkim->dkim_libhandle, dkim->dkim_closure,
-		           cur->canon_hash);
+
+		dkim_canon_free(dkim, cur);
+
 		cur = next;
 	}
+
+	dkim->dkim_canonhead = NULL;
 }
 
 /*
@@ -1251,7 +1254,7 @@ dkim_canon_signature(DKIM *dkim, struct dkim_header *hdr)
 }
 
 /*
-**  DKIM_CANON_MINBODY -- return number of bytes required to satisfy
+**  DKIM_CANON_MINBODY -- return number of bytes required to satisfy all
 **                        canonicalizations
 **
 **  Parameters:
@@ -1282,7 +1285,7 @@ dkim_canon_minbody(DKIM *dkim)
 			return ULONG_MAX;
 
 		/* compare to current minimum */
-		minbody = MIN(minbody, (u_long) cur->canon_remain);
+		minbody = MAX(minbody, (u_long) cur->canon_remain);
 	}
 
 	return minbody;
