@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.35 2008/03/17 16:40:07 msk Exp $";
+static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.37 2008/05/20 18:38:05 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -33,6 +33,8 @@ static char dkim_keys_c_id[] = "@(#)$Id: dkim-keys.c,v 1.35 2008/03/17 16:40:07
 #include "dkim-types.h"
 #include "dkim-keys.h"
 #include "dkim-cache.h"
+#include "dkim-test.h"
+#include "util.h"
 #include "dkim.h"
 
 /* prototypes */
@@ -124,20 +126,76 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 	}
 #endif /* QUERY_CACHE */
 
+	/* see if there's a simulated reply queued; if so, use it */
+	anslen = dkim_test_dns_get(dkim, ansbuf, sizeof ansbuf);
+	if (anslen == -1)
+	{
 #if USE_ARLIB
 # ifdef _FFR_DNS_UPGRADE
-	for (c = 0; c < 2; c++)
-	{
-		switch (c)
+		for (c = 0; c < 2; c++)
 		{
-		  case 0:
-			ar = dkim->dkim_libhandle->dkiml_arlib;
-			break;
+			switch (c)
+			{
+			  case 0:
+				ar = dkim->dkim_libhandle->dkiml_arlib;
+				break;
+
+			  case 1:
+				ar = dkim->dkim_libhandle->dkiml_arlibtcp;
+				break;
+			}
+
+			timeout.tv_sec = dkim->dkim_timeout;
+			timeout.tv_usec = 0;
+
+			q = ar_addquery(ar, qname, C_IN, T_TXT, MAXCNAMEDEPTH,
+			                ansbuf, sizeof ansbuf, &error,
+			                dkim->dkim_timeout == 0 ? NULL
+			                                        : &timeout);
+			if (q == NULL)
+			{
+				dkim_error(dkim,
+				           "ar_addquery() for `%s' failed",
+				           qname);
+				return DKIM_STAT_INTERNAL;
+			}
+
+			if (lib->dkiml_dns_callback == NULL)
+			{
+				status = ar_waitreply(ar, q, &anslen, NULL);
+			}
+			else
+			{
+				for (;;)
+				{
+					timeout.tv_sec = lib->dkiml_callback_int;
+					timeout.tv_usec = 0;
+
+					status = ar_waitreply(ar, q, &anslen,
+					                      &timeout);
+
+					if (status != AR_STAT_NOREPLY)
+						break;
+
+					lib->dkiml_dns_callback(dkim->dkim_user_context);
+				}
+			}
+
+			(void) ar_cancelquery(ar, q);
+
+			/* see if the UDP reply was truncated */
+			if (c == 0 && status == AR_STAT_SUCCESS)
+			{
+				memcpy(&hdr, ansbuf, sizeof hdr);
+				if (dkim_check_dns_reply(ansbuf, anslen,
+			                         C_IN, T_TXT) == 1)
+					continue;
+			}
 
-		  case 1:
-			ar = dkim->dkim_libhandle->dkiml_arlibtcp;
 			break;
 		}
+# else /* _FFR_DNS_UPGRADE */
+		ar = dkim->dkim_libhandle->dkiml_arlib;
 
 		timeout.tv_sec = dkim->dkim_timeout;
 		timeout.tv_usec = 0;
@@ -174,93 +232,46 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 		}
 
 		(void) ar_cancelquery(ar, q);
-
-		/* see if the UDP reply was truncated */
-		if (c == 0 && status == AR_STAT_SUCCESS)
-		{
-			memcpy(&hdr, ansbuf, sizeof hdr);
-			if (dkim_check_dns_reply(ansbuf, anslen,
-			                         C_IN, T_TXT) == 2)
-				continue;
-		}
-
-		break;
-	}
-# else /* _FFR_DNS_UPGRADE */
-	ar = dkim->dkim_libhandle->dkiml_arlib;
-
-	timeout.tv_sec = dkim->dkim_timeout;
-	timeout.tv_usec = 0;
-
-	q = ar_addquery(ar, qname, C_IN, T_TXT, MAXCNAMEDEPTH, ansbuf,
-	                sizeof ansbuf, &error,
-	                dkim->dkim_timeout == 0 ? NULL : &timeout);
-	if (q == NULL)
-	{
-		dkim_error(dkim, "ar_addquery() for `%s' failed", qname);
-		return DKIM_STAT_INTERNAL;
-	}
-
-	if (lib->dkiml_dns_callback == NULL)
-	{
-		status = ar_waitreply(ar, q, &anslen, NULL);
-	}
-	else
-	{
-		for (;;)
-		{
-			timeout.tv_sec = lib->dkiml_callback_int;
-			timeout.tv_usec = 0;
-
-			status = ar_waitreply(ar, q, &anslen, &timeout);
-
-			if (status != AR_STAT_NOREPLY)
-				break;
-
-			lib->dkiml_dns_callback(dkim->dkim_user_context);
-		}
-	}
-
-	(void) ar_cancelquery(ar, q);
 # endif /* _FFR_DNS_UPGRADE */
 #else /* USE_ARLIB */
-	status = res_query(qname, C_IN, T_TXT, ansbuf, sizeof ansbuf);
+		status = res_query(qname, C_IN, T_TXT, ansbuf, sizeof ansbuf);
 #endif /* USE_ARLIB */
 
 #if USE_ARLIB
-	if (status == AR_STAT_ERROR || status == AR_STAT_EXPIRED)
-	{
-		dkim_error(dkim, "ar_waitreply(): `%s' %s", qname,
-		           status == AR_STAT_ERROR ? "error"
-		                                   : "expired");
-		return DKIM_STAT_KEYFAIL;
-	}
-#else /* USE_ARLIB */
-	/*
-	**  A -1 return from res_query could mean a bunch of things,
-	**  not just NXDOMAIN.  You can use h_errno to determine what
-	**  -1 means.  This is poorly documented.
-	*/
-
-	if (status == -1)
-	{
-		switch (h_errno)
+		if (status == AR_STAT_ERROR || status == AR_STAT_EXPIRED)
 		{
-		  case HOST_NOT_FOUND:
-		  case NO_DATA:
-			return DKIM_STAT_NOKEY;
-
-		  case TRY_AGAIN:
-		  case NO_RECOVERY:
-		  default:
-			dkim_error(dkim, "res_query(): `%s' %s",
-			           qname, hstrerror(h_errno));
+			dkim_error(dkim, "ar_waitreply(): `%s' %s", qname,
+			           status == AR_STAT_ERROR ? "error"
+			                                   : "expired");
 			return DKIM_STAT_KEYFAIL;
 		}
-	}
+#else /* USE_ARLIB */
+		/*
+		**  A -1 return from res_query could mean a bunch of things,
+		**  not just NXDOMAIN.  You can use h_errno to determine what
+		**  -1 means.  This is poorly documented.
+		*/
 
-	anslen = status;
+		if (status == -1)
+		{
+			switch (h_errno)
+			{
+			  case HOST_NOT_FOUND:
+			  case NO_DATA:
+				return DKIM_STAT_NOKEY;
+
+			  case TRY_AGAIN:
+			  case NO_RECOVERY:
+			  default:
+				dkim_error(dkim, "res_query(): `%s' %s",
+				           qname, hstrerror(h_errno));
+				return DKIM_STAT_KEYFAIL;
+			}
+		}
+
+		anslen = status;
 #endif /* USE_ARLIB */
+	}
 
 	/* set up pointers */
 	memcpy(&hdr, ansbuf, sizeof hdr);
@@ -304,7 +315,7 @@ dkim_get_key_dns(DKIM *dkim, DKIM_SIGINFO *sig, u_char *buf, size_t buflen)
 		return DKIM_STAT_NOKEY;
 
 	/* if truncated, we can't do it */
-	if (dkim_check_dns_reply(ansbuf, anslen, C_IN, T_TXT) == 2)
+	if (dkim_check_dns_reply(ansbuf, anslen, C_IN, T_TXT) == 1)
 	{
 		dkim_error(dkim, "`%s' reply truncated", qname);
 		return DKIM_STAT_INTERNAL;
