@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_policy_c_id[] = "@(#)$Id: dkim-policy.c,v 1.30 2008/04/11 23:15:17 msk Exp $";
+static char dkim_policy_c_id[] = "@(#)$Id: dkim-policy.c,v 1.32 2008/05/20 18:38:05 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -36,6 +36,8 @@ static char dkim_policy_c_id[] = "@(#)$Id: dkim-policy.c,v 1.30 2008/04/11 23:15
 #ifdef QUERY_CACHE
 # include "dkim-cache.h"
 #endif /* QUERY_CACHE */
+#include "dkim-test.h"
+#include "util.h"
 
 /* prototypes */
 extern void dkim_error __P((DKIM *, const char *, ...));
@@ -221,20 +223,76 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *query, bool usemx,
 
 	qtype = (usemx ? T_MX : T_TXT);
 
+	/* see if there's a simulated reply queued; if so, use it */
+	anslen = dkim_test_dns_get(dkim, ansbuf, sizeof ansbuf);
+	if (anslen == -1)
+	{
 #if USE_ARLIB
 # ifdef _FFR_DNS_UPGRADE
-	for (c = 0; c < 2; c++)
-	{
-		switch (c)
+		for (c = 0; c < 2; c++)
 		{
-		  case 0:
-			ar = dkim->dkim_libhandle->dkiml_arlib;
-			break;
+			switch (c)
+			{
+			  case 0:
+				ar = dkim->dkim_libhandle->dkiml_arlib;
+				break;
+
+			  case 1:
+				ar = dkim->dkim_libhandle->dkiml_arlibtcp;
+				break;
+			}
+
+			timeout.tv_sec = dkim->dkim_timeout;
+			timeout.tv_usec = 0;
+
+			q = ar_addquery(ar, query, C_IN, qtype, MAXCNAMEDEPTH,
+			                ansbuf, sizeof ansbuf, &arerror,
+			                dkim->dkim_timeout == 0 ? NULL
+			                                        : &timeout);
+			if (q == NULL)
+			{
+				dkim_error(dkim,
+				           "ar_addquery() for `%s' failed",
+				           query);
+				return -1;
+			}
+
+			if (lib->dkiml_dns_callback == NULL)
+			{
+				status = ar_waitreply(ar, q, &anslen, NULL);
+			}
+			else
+			{
+				for (;;)
+				{
+					timeout.tv_sec = lib->dkiml_callback_int;
+					timeout.tv_usec = 0;
+
+					status = ar_waitreply(ar, q, &anslen,
+					                      &timeout);
+
+					if (status != AR_STAT_NOREPLY)
+						break;
+
+					lib->dkiml_dns_callback(dkim->dkim_user_context);
+				}
+			}
+
+			(void) ar_cancelquery(ar, q);
+
+			/* see if the UDP reply was truncated */
+			if (c == 0 && status == AR_STAT_SUCCESS)
+			{
+				memcpy(&hdr, ansbuf, sizeof hdr);
+				if (dkim_check_dns_reply(ansbuf, anslen,
+				                         C_IN, T_TXT) == 1)
+					continue;
+			}
 
-		  case 1:
-			ar = dkim->dkim_libhandle->dkiml_arlibtcp;
 			break;
 		}
+# else /* _FFR_DNS_UPGRADE */
+		ar = dkim->dkim_libhandle->dkiml_arlib;
 
 		timeout.tv_sec = dkim->dkim_timeout;
 		timeout.tv_usec = 0;
@@ -244,7 +302,7 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *query, bool usemx,
 		                dkim->dkim_timeout == 0 ? NULL : &timeout);
 		if (q == NULL)
 		{
-			dkim_error(dkim, "ar_addquery() for `%s' failed",
+			dkim_error(dkim, "ar_addquery() failed for `%s'",
 			           query);
 			return -1;
 		}
@@ -271,110 +329,64 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *query, bool usemx,
 		}
 
 		(void) ar_cancelquery(ar, q);
-
-		/* see if the UDP reply was truncated */
-		if (c == 0 && status == AR_STAT_SUCCESS)
-		{
-			memcpy(&hdr, ansbuf, sizeof hdr);
-			if (dkim_check_dns_reply(ansbuf, anslen,
-			                         C_IN, T_TXT) == 2)
-				continue;
-		}
-
-		break;
-	}
-# else /* _FFR_DNS_UPGRADE */
-	ar = dkim->dkim_libhandle->dkiml_arlib;
-
-	timeout.tv_sec = dkim->dkim_timeout;
-	timeout.tv_usec = 0;
-
-	q = ar_addquery(ar, query, C_IN, qtype, MAXCNAMEDEPTH, ansbuf,
-	                sizeof ansbuf, &arerror,
-	                dkim->dkim_timeout == 0 ? NULL : &timeout);
-	if (q == NULL)
-	{
-		dkim_error(dkim, "ar_addquery() failed for `%s'", query);
-		return -1;
-	}
-
-	if (lib->dkiml_dns_callback == NULL)
-	{
-		status = ar_waitreply(ar, q, &anslen, NULL);
-	}
-	else
-	{
-		for (;;)
-		{
-			timeout.tv_sec = lib->dkiml_callback_int;
-			timeout.tv_usec = 0;
-
-			status = ar_waitreply(ar, q, &anslen, &timeout);
-
-			if (status != AR_STAT_NOREPLY)
-				break;
-
-			lib->dkiml_dns_callback(dkim->dkim_user_context);
-		}
-	}
-
-	(void) ar_cancelquery(ar, q);
 # endif /* _FFR_DNS_UPGRADE */
 #else /* USE_ARLIB */
 
-	status = res_query(query, C_IN, qtype, ansbuf, sizeof ansbuf);
+		status = res_query(query, C_IN, qtype, ansbuf, sizeof ansbuf);
 
 #endif /* USE_ARLIB */
 
 #if USE_ARLIB
-	if (status == AR_STAT_ERROR || status == AR_STAT_EXPIRED)
-	{
-		dkim_error(dkim, "ar_waitreply(): `%s' query %s",
-		           query,
-		           status == AR_STAT_ERROR ? "error" : "expired");
+		if (status == AR_STAT_ERROR || status == AR_STAT_EXPIRED)
+		{
+			dkim_error(dkim, "ar_waitreply(): `%s' query %s",
+			           query,
+			           status == AR_STAT_ERROR ? "error"
+			                                   : "expired");
 
-		if (status == AR_STAT_EXPIRED)
-		{
-			*qstatus = SERVFAIL;
-			return 0;
+			if (status == AR_STAT_EXPIRED)
+			{
+				*qstatus = SERVFAIL;
+				return 0;
+			}
+			else
+			{
+				return -1;
+			}
 		}
-		else
-		{
-			return -1;
-		}
-	}
 
 #else /* USE_ARLIB */
-	/*
-	**  A -1 return from res_query could mean a bunch of things,
-	**  not just NXDOMAIN.  You can use h_errno to determine what
-	**  -1 means.  This is poorly documented.
-	*/
+		/*
+		**  A -1 return from res_query could mean a bunch of things,
+		**  not just NXDOMAIN.  You can use h_errno to determine what
+		**  -1 means.  This is poorly documented.
+		*/
 
-	if (status == -1)
-	{
-		switch (h_errno)
+		if (status == -1)
 		{
-		  case HOST_NOT_FOUND:
-			*qstatus = NXDOMAIN;
-			return 0;
+			switch (h_errno)
+			{
+			  case HOST_NOT_FOUND:
+				*qstatus = NXDOMAIN;
+				return 0;
 
-		  case NO_DATA:
-			*qstatus = NOERROR;
-			return 0;
+			  case NO_DATA:
+				*qstatus = NOERROR;
+				return 0;
 
-		  case TRY_AGAIN:
-		  case NO_RECOVERY:
-		  default:
-			dkim_error(dkim, "res_query(): `%s' %s",
-			           query, hstrerror(h_errno));
-			*qstatus = SERVFAIL;
-			return 0;
+			  case TRY_AGAIN:
+			  case NO_RECOVERY:
+			  default:
+				dkim_error(dkim, "res_query(): `%s' %s",
+				           query, hstrerror(h_errno));
+				*qstatus = SERVFAIL;
+				return 0;
+			}
 		}
-	}
 
-	anslen = status;
+		anslen = status;
 #endif /* USE_ARLIB */
+	}
 
 	/* set up pointers */
 	memcpy(&hdr, ansbuf, sizeof hdr);
@@ -416,7 +428,7 @@ dkim_get_policy_dns(DKIM *dkim, unsigned char *query, bool usemx,
 	}
 
 	/* if truncated, we can't do it */
-	if (dkim_check_dns_reply(ansbuf, anslen, C_IN, T_TXT) == 2)
+	if (dkim_check_dns_reply(ansbuf, anslen, C_IN, T_TXT) == 1)
 	{
 		dkim_error(dkim, "reply for `%s' truncated", query);
 		return -1;
