@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_tables_c_id[] = "@(#)$Id: dkim-tables.c,v 1.39 2008/04/14 20:02:19 msk Exp $";
+static char dkim_tables_c_id[] = "@(#)$Id: dkim-tables.c,v 1.41 2008/05/19 23:57:40 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -210,6 +210,14 @@ static struct nametable prv_sigerrors[] =	/* signature parsing errors */
 	{ "header list tag empty",		DKIM_SIGERROR_EMPTY_H },
 	{ "header list missing required entries", DKIM_SIGERROR_INVALID_H },
 	{ "length tag value exceeds body size", DKIM_SIGERROR_TOOLARGE_L },
+	{ "unprotected header field",		DKIM_SIGERROR_MBSFAILED },
+	{ "unknown key version",		DKIM_SIGERROR_KEYVERSION },
+	{ "unknown key hash",			DKIM_SIGERROR_KEYUNKNOWNHASH },
+	{ "signature-key hash mismatch",	DKIM_SIGERROR_KEYHASHMISMATCH },
+	{ "not an e-mail key",			DKIM_SIGERROR_NOTEMAILKEY },
+	{ "key granularity mismatch",		DKIM_SIGERROR_GRANULARITY },
+	{ "key type missing",			DKIM_SIGERROR_KEYTYPEMISSING },
+	{ "unknown key type",			DKIM_SIGERROR_KEYTYPEUNKNOWN },
 	{ NULL,					-1 },
 };
 struct nametable *sigerrors = prv_sigerrors;
