@@ -4,20 +4,26 @@
 */
 
 #ifndef lint
-static char dkim_test_c_id[] = "@(#)$Id: dkim-test.c,v 1.9 2008/02/26 00:04:31 msk Exp $";
+static char dkim_test_c_id[] = "@(#)$Id: dkim-test.c,v 1.11 2008/05/27 21:53:33 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
 #include <sys/param.h>
 #include <sys/types.h>
+#include <arpa/nameser.h>
+#include <netinet/in.h>
 #include <assert.h>
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
+#include <resolv.h>
 #include <errno.h>
 
 /* libsm includes */
+#include <sm/gen.h>
 #include <sm/string.h>
+#include <sm/types.h>
+#include <sm/cdefs.h>
 
 /* openssl includes */
 #include <openssl/bio.h>
@@ -31,9 +37,227 @@ static char dkim_test_c_id[] = "@(#)$Id: dkim-test.c,v 1.9 2008/02/26 00:04:31 m
 #include "dkim-test.h"
 #include "dkim.h"
 
+/* definitions */
+#define	TESTTTL			300
+#define MAXPACKET		8192
+
 /* prototypes from elsewhere */
 extern DKIM_STAT dkim_get_key __P((DKIM *, DKIM_SIGINFO *));
 
+/*
+**  DKIM_TEST_DNS_PUT -- enqueue a DNS reply for automated testing
+**
+**  Parameters:
+**  	dkim -- DKIM handle
+**  	class -- class of the reply
+**  	type -- type of the reply
+**  	prec -- precedence (for MX replies)
+**  	name -- name of the reply (i.e. the "question")
+**  	data -- content of the reply
+**
+**  Return value:
+**  	0 -- success
+**  	-1 -- failure (e.g. malloc() failed)
+*/
+
+int
+dkim_test_dns_put(DKIM *dkim, int class, int type, int prec, u_char *name,
+                  u_char *data)
+{
+	struct dkim_test_dns_data *td;
+
+	assert(dkim != NULL);
+	assert(name != NULL);
+
+	td = (struct dkim_test_dns_data *) DKIM_MALLOC(dkim, sizeof *td);
+	if (td == NULL)
+		return -1;
+
+	td->dns_class = class;
+	td->dns_type = type;
+	td->dns_prec = prec;
+
+	td->dns_query = dkim_strdup(dkim, name, 0);
+	if (td->dns_query == NULL)
+	{
+		DKIM_FREE(dkim, td);
+		return -1;
+	}
+
+	if (data != NULL)
+	{
+		td->dns_reply = dkim_strdup(dkim, data, 0);
+		if (td->dns_reply == NULL)
+		{
+			DKIM_FREE(dkim, td->dns_query);
+			DKIM_FREE(dkim, td);
+			return -1;
+		}
+	}
+
+	td->dns_next = NULL;
+
+	if (dkim->dkim_dnstesth == NULL)
+		dkim->dkim_dnstesth = td;
+	else
+		dkim->dkim_dnstestt->dns_next = td;
+
+	dkim->dkim_dnstestt = td;
+
+	return 0;
+}
+
+/*
+**  DKIM_TEST_DNS_GET -- dequeue a DNS reply for automated testing
+**
+**  Parameters:
+**  	dkim -- DKIM handle
+**  	buf -- target buffer
+**  	buflen -- bytes available at "buf"
+**
+**  Return value:
+**  	-1 -- nothing queued
+**  	other -- size of the reply
+*/
+
+size_t
+dkim_test_dns_get(DKIM *dkim, u_char *buf, size_t buflen)
+{
+	int n;
+	int len;
+	int testttl;
+	struct dkim_test_dns_data *td;
+	u_char *cp;
+	u_char *p;
+	u_char *end;
+	u_char answer[MAXPACKET];
+	HEADER hdr;
+
+	td = dkim->dkim_dnstesth;
+	if (td == NULL)
+		return -1;
+
+	dkim->dkim_dnstesth = td->dns_next;
+
+	/* encode the reply */
+	memset(&hdr, '\0', sizeof hdr);
+	hdr.qdcount = htons(1);
+	hdr.rcode = (td->dns_reply == NULL ? NXDOMAIN : NOERROR);
+	hdr.ancount = (td->dns_reply == NULL ? htons(0) : htons(1));
+
+	memcpy(answer, &hdr, sizeof hdr);
+
+	cp = answer + HFIXEDSZ;
+	end = answer + sizeof answer;
+
+	/* dn_comp(const char *exp_dn, u_char *comp_dn, int length, u_char **dnptrs, uchar **lastdnptr) */
+	
+	/* repeat the question */
+	n = dn_comp(td->dns_query, cp, end - cp, NULL, NULL);
+	if (n < 0)
+	{
+		DKIM_FREE(dkim, td);
+		return -1;
+	}
+	cp += n;
+	if (end - cp < 2 * sizeof(uint16_t))
+	{
+		DKIM_FREE(dkim, td);
+		return -1;
+	}
+
+	PUTSHORT(td->dns_type, cp);
+	PUTSHORT(td->dns_class, cp);
+
+	/* short-circuit? */
+	if (hdr.rcode == NXDOMAIN)
+	{
+		DKIM_FREE(dkim, td);
+
+		memcpy(buf, answer, buflen);
+
+		return cp - answer;
+	}
+
+	/* the answer starts out the same way */
+	n = dn_comp(td->dns_query, cp, end - cp, NULL, NULL);
+	if (n < 0)
+	{
+		DKIM_FREE(dkim, td);
+		return -1;
+	}
+	cp += n;
+
+	if (end - cp < 2 * sizeof(uint16_t) + sizeof(uint32_t))
+	{
+		DKIM_FREE(dkim, td);
+		return -1;
+	}
+
+	PUTSHORT(td->dns_type, cp);
+	PUTSHORT(td->dns_class, cp);
+
+	testttl = htonl(TESTTTL);
+	PUTLONG(testttl, cp);
+
+	switch (td->dns_type)
+	{
+	  case T_TXT:
+		/* figure out how many bytes we need total */
+		n = strlen(td->dns_reply);
+		len = n + n / 255 + 1;
+		if (end - cp < len + sizeof(uint16_t))
+		{
+			DKIM_FREE(dkim, td);
+			return -1;
+		}
+		PUTSHORT(len, cp);
+
+		/* write the buffer, inserting length bytes as needed */
+		len = 0;
+		p = td->dns_reply;
+		while (n > 0)
+		{
+			if (len == 0)
+			{
+				len = MIN(255, n);
+				*cp++ = len;
+			}
+			*cp++ = *p++;
+			n--;
+			len--;
+		}
+		break;
+
+	  case T_MX:
+		if (end - cp < sizeof(uint16_t))
+		{
+			DKIM_FREE(dkim, td);
+			return -1;
+		}
+		PUTSHORT(td->dns_prec, cp);
+		n = dn_comp(td->dns_reply, cp, end - cp, NULL, NULL);
+		if (n < 0)
+		{
+			DKIM_FREE(dkim, td);
+			return -1;
+		}
+
+		cp += n;
+		break;
+
+	  default:
+		DKIM_FREE(dkim, td);
+		return -1;
+	}
+
+	DKIM_FREE(dkim, td);
+
+	memcpy(buf, answer, buflen);
+
+	return cp - answer;
+}
+
 /*
 **  DKIM_TEST_KEY -- retrieve a public key and verify it against a provided
 **                   private key
@@ -65,6 +289,7 @@ dkim_test_key(DKIM_LIB *lib, char *selector, char *domain,
 	BIO *outkey;
 	void *ptr;
 	struct dkim_rsa *rsa;
+	char buf[BUFRSZ];
 
 	assert(lib != NULL);
 	assert(selector != NULL);
@@ -78,36 +303,24 @@ dkim_test_key(DKIM_LIB *lib, char *selector, char *domain,
 		return -1;
 	}
 
-	dkim->dkim_siglist = DKIM_MALLOC(dkim, sizeof(sig) * 2);
-	if (dkim->dkim_siglist == NULL)
+	snprintf(buf, sizeof buf, "d=%s; s=%s; h=x; b=x; v=x; a=x",
+	         domain, selector);
+
+	stat = dkim_process_set(dkim, DKIM_SETTYPE_SIGNATURE, buf, strlen(buf),
+	                        NULL, FALSE);
+	if (stat != DKIM_STAT_OK)
 	{
-		(void) dkim_free(dkim);
-		if (err != NULL)
-		{
-			snprintf(err, errlen, "unable to allocate %d byte(s)",
-			         sizeof(sig) * 2);
-		}
+		sm_strlcpy(err, "syntax error on input", errlen);
 		return -1;
 	}
 
-	dkim->dkim_siglist[1] = NULL;
-	dkim->dkim_siglist[0] = DKIM_MALLOC(dkim, sizeof *sig);
-	if (dkim->dkim_siglist[0] == NULL)
-	{
-		(void) dkim_free(dkim);
-		if (err != NULL)
-		{
-			snprintf(err, errlen, "unable to allocate %d byte(s)",
-			         sizeof *sig);
-		}
+	dkim->dkim_sigcount = 1;
+
+	stat = dkim_siglist_setup(dkim);
+	if (status != DKIM_STAT_OK)
 		return -1;
-	}
 
 	sig = dkim->dkim_siglist[0];
-	memset(sig, '\0', sizeof *sig);
-
-	sig->sig_domain = domain;
-	sig->sig_selector = selector;
 
 	dkim->dkim_user = dkim_strdup(dkim, "nobody", 0);
 	if (dkim->dkim_user == NULL)
