@@ -7,7 +7,7 @@
 #define _DKIM_TEST_H_
 
 #ifndef lint
-static char dkim_test_h_id[] = "@(#)$Id: dkim-test.h,v 1.6 2008/02/26 00:04:31 msk Exp $";
+static char dkim_test_h_id[] = "@(#)$Id: dkim-test.h,v 1.7 2008/05/13 19:56:54 msk Exp $";
 #endif /* !lint */
 
 /* libdkim includes */
@@ -19,4 +19,7 @@ extern int dkim_test_asp __P((DKIM_LIB *, char *, dkim_policy_t *,
 extern int dkim_test_key __P((DKIM_LIB *, char *, char *, char *, size_t,
                               char *, size_t));
 
+extern size_t dkim_test_dns_get __P((DKIM *, u_char *, size_t));
+extern int dkim_test_dns_put __P((DKIM *, int, int, int, u_char *, u_char *));
+
 #endif /* ! _DKIM_TEST_H_ */
