@@ -7,7 +7,7 @@
 #define _DKIM_TYPES_H_
 
 #ifndef lint
-static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.86 2008/02/26 00:04:31 msk Exp $";
+static char dkim_types_h_id[] = "@(#)$Id: dkim-types.h,v 1.89 2008/06/05 15:18:19 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -177,6 +177,17 @@ struct dkim_rsa
 	u_char *		rsa_rsaout;
 };
 
+/* struct dkim_test_dns_data -- simulated DNS replies */
+struct dkim_test_dns_data
+{
+	int			dns_class;
+	int			dns_type;
+	int			dns_prec;
+	u_char *		dns_query;
+	u_char *		dns_reply;
+	struct dkim_test_dns_data * dns_next;
+};
+
 /* struct dkim -- a complete DKIM transaction context */
 struct dkim
 {
@@ -197,6 +208,7 @@ struct dkim
 #endif /* QUERY_CACHE */
 	u_int			dkim_version;
 	u_int			dkim_sigcount;
+	size_t			dkim_margin;
 	size_t			dkim_b64siglen;
 	size_t			dkim_keylen;
 	size_t			dkim_errlen;
@@ -238,6 +250,8 @@ struct dkim
 	struct dkim_canon *	dkim_canontail;
 	struct dkim_dstring *	dkim_hdrbuf;
 	struct dkim_dstring *	dkim_canonbuf;
+	struct dkim_test_dns_data * dkim_dnstesth;
+	struct dkim_test_dns_data * dkim_dnstestt;
 	DKIM_LIB *		dkim_libhandle;
 };
 
@@ -264,6 +278,7 @@ struct dkim_lib
 #endif /* USE_ARLIB */
 	u_char **		dkiml_senderhdrs;
 	u_char **		dkiml_alwayshdrs;
+	u_char **		dkiml_mbs;
 #ifdef QUERY_CACHE
 	DB *			dkiml_cache;
 #endif /* QUERY_CACHE */
