@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char dkim_util_c_id[] = "@(#)$Id: dkim-util.c,v 1.21 2008/02/04 21:40:12 msk Exp $";
+static char dkim_util_c_id[] = "@(#)$Id: dkim-util.c,v 1.22 2008/05/08 18:59:25 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -256,7 +256,7 @@ dkim_dstring_new(DKIM *dkim, int len, int maxlen)
 	assert(dkim != NULL);
 
 	/* fail on invalid parameters */
-	if ((maxlen > 0 && len > maxlen) || len == 0)
+	if ((maxlen > 0 && len > maxlen) || len < 0)
 		return NULL;
 
 	lib = dkim->dkim_libhandle;
