@@ -7,7 +7,7 @@
 #define _DKIM_H_
 
 #ifndef lint
-static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.175 2008/04/22 21:54:00 msk Exp $";
+static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.182 2008/06/05 15:19:36 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -31,7 +31,7 @@ static char dkim_h_id[] = "@(#)$Id: dkim.h,v 1.175 2008/04/22 21:54:00 msk Exp $
 **  	pp == patch number
 */
 
-#define	DKIM_LIB_VERSION	0x02050500
+#define	DKIM_LIB_VERSION	0x02060000
 
 /* the basics */
 #ifndef NULL
@@ -178,6 +178,15 @@ typedef int DKIM_SIGERROR;
 #define DKIM_SIGERROR_EMPTY_H		31	/* h= empty */
 #define DKIM_SIGERROR_INVALID_H		32	/* h= missing req'd entries */
 #define DKIM_SIGERROR_TOOLARGE_L	33	/* l= value exceeds body size */
+#define DKIM_SIGERROR_MBSFAILED		34	/* "must be signed" failure */
+#define	DKIM_SIGERROR_KEYVERSION	35	/* unknown key version */
+#define	DKIM_SIGERROR_KEYUNKNOWNHASH	36	/* unknown key hash */
+#define	DKIM_SIGERROR_KEYHASHMISMATCH	37	/* sig-key hash mismatch */
+#define	DKIM_SIGERROR_NOTEMAILKEY	38	/* not an e-mail key */
+#define	DKIM_SIGERROR_GRANULARITY	39	/* key granularity mismatch */
+#define	DKIM_SIGERROR_KEYTYPEMISSING	40	/* key type missing */
+#define	DKIM_SIGERROR_KEYTYPEUNKNOWN	41	/* key type unknown */
+#define	DKIM_SIGERROR_KEYREVOKED	42	/* key revoked */
 
 /*
 **  DKIM_CANON -- canonicalization method
@@ -364,6 +373,7 @@ typedef int dkim_opts_t;
 #define	DKIM_OPTS_ALWAYSHDRS	10
 #define	DKIM_OPTS_SIGNATURETTL	11
 #define	DKIM_OPTS_CLOCKDRIFT	12
+#define	DKIM_OPTS_MUSTBESIGNED	13
 
 #define	DKIM_LIBFLAGS_NONE		0x000
 #define	DKIM_LIBFLAGS_TMPFILES		0x001
@@ -755,7 +765,6 @@ extern DKIM_SIGINFO *dkim_getsignature __P((DKIM *dkim));
 **  	dkim -- a DKIM handle previously returned by dkim_sign()
 **  	buf -- buffer into which to write the signature
 **  	len -- number of bytes available at "sig"
-**  	margin -- attempt to wrap the header at the specified length
 **  	initial -- width of the first line
 **
 **  Return value:
@@ -763,7 +772,46 @@ extern DKIM_SIGINFO *dkim_getsignature __P((DKIM *dkim));
 */
 
 extern DKIM_STAT dkim_getsighdr __P((DKIM *dkim, u_char *buf, size_t len,
-                                     size_t margin, size_t initial));
+                                     size_t initial));
+
+/*
+**  DKIM_SIG_HDRSIGNED -- retrieve the header list from a signature
+**
+**  Parameters:
+**  	sig -- DKIM_SIGINFO handle
+**  	hdr -- header name to find
+**
+**  Return value:
+**  	TRUE iff "sig" had a header list in it and the header "hdr"
+**  	appeared in that list.
+*/
+
+extern bool dkim_sig_hdrsigned __P((DKIM_SIGINFO *sig, char *hdr));
+
+/*
+**  DKIM_SIG_GETREPORTINFO -- retrieve reporting information from a key
+**
+**  Parameters:
+**  	dkim -- DKIM handle
+**  	sig -- DKIM_SIGINFO handle
+**  	hfd -- canonicalized header descriptor (returned)
+**  	bfd -- canonicalized body descriptor (returned)
+**  	addr -- address buffer
+**  	addrlen -- size of addr
+**  	fmt -- format buffer (or NULL)
+**  	fmtlen -- size of fmt
+**  	opts -- options buffer (or NULL)
+**  	optslen -- size of opts
+**
+**  Return value:
+**  	A DKIM_STAT_* constant.
+*/
+
+extern DKIM_STAT dkim_sig_getreportinfo __P((DKIM *dkim, DKIM_SIGINFO *sig,
+                                             int *hfd, int *bfd,
+                                             u_char *addr, size_t addrlen,
+                                             u_char *fmt, size_t fmtlen,
+                                             u_char *opts, size_t optslen));
 
 /*
 **  DKIM_SIG_GETIDENTITY -- retrieve identity of the signer
@@ -805,25 +853,6 @@ extern DKIM_STAT dkim_sig_getcanonlen __P((DKIM *dkim, DKIM_SIGINFO *sig,
                                            off_t *msglen, off_t *canonlen,
                                            off_t *signlen));
 
-/*
-**  DKIM_REPORTINFO -- return info needed to generate failure report
-**
-**  Parameters:
-**  	dkim -- a DKIM handle previously returned by dkim_verify()
-**  	sig -- a DKIM_SIGINFO handle previously returned by dkim_getsignature()
-**  	fd -- pointer to receive temporary file descriptor
-**  	bfd -- pointer to receive temporary body file descriptor
-**   	raddr -- buffer to receive report address
-**  	rlen -- bytes available at raddr
-**
-**  Return vlalue:
-**  	A DKIM_STAT value.
-*/
-
-extern DKIM_STAT dkim_reportinfo __P((DKIM *dkim, DKIM_SIGINFO *sig,
-                                      int *fd, int *bfd,
-                                      u_char *raddr, size_t rlen));
-
 /*
 **  DKIM_OPTIONS -- set/get options
 **
@@ -1221,6 +1250,27 @@ extern void dkim_sig_ignore __P((DKIM_SIGINFO *siginfo));
 extern DKIM_STAT dkim_policy __P((DKIM *dkim, dkim_policy_t *pcode,
                                   DKIM_PSTATE *pstate));
 
+/*
+**  DKIM_POLICY_GETREPORTINFO -- retrieve reporting information from policy
+**
+**  Parameters:
+**  	dkim -- DKIM handle
+**  	addr -- address buffer
+**  	addrlen -- size of addr
+**  	fmt -- format buffer (or NULL)
+**  	fmtlen -- size of fmt
+**  	opts -- options buffer (or NULL)
+**  	optslen -- size of opts
+**
+**  Return value:
+**  	A DKIM_STAT_* constant.
+*/
+
+extern DKIM_STAT dkim_policy_getreportinfo __P((DKIM *dkim,
+                                                u_char *addr, size_t addrlen,
+                                                u_char *fmt, size_t fmtlen,
+                                                u_char *opts, size_t optslen));
+
 /*
 **  DKIM_SIG_PROCESS -- process a signature
 **
@@ -1377,6 +1427,21 @@ extern bool dkim_getpartial __P((DKIM *dkim));
 extern DKIM_STAT dkim_setpartial __P((DKIM *dkim, bool value));
 #endif /* _FFR_BODYLENGTH_DB */
 
+/*
+**  DKIM_SET_MARGIN -- set the margin to use when generating signatures
+**
+**  Parameters:
+**      dkim -- DKIM handle
+**      value -- new margin value
+**
+**  Return value:
+**      DKIM_STAT_INVALID -- "dkim" referenced a verification handle, or
+**  	                     "value" was negative
+**      DKIM_STAT_OK -- otherwise
+*/
+
+extern DKIM_STAT dkim_set_margin __P((DKIM *dkim, int value));
+
 /*
 **  RFC2822_MAILBOX_SPLIT -- extract the userid and host from a structured
 **                           header
