@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char t_test09_c_id[] = "@(#)$Id: t-test09.c,v 1.9 2007/08/20 16:52:04 msk Exp $";
+static char t_test09_c_id[] = "@(#)$Id: t-test09.c,v 1.10 2008/06/05 15:23:18 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -146,12 +146,7 @@ main(int argc, char **argv)
 	assert(status == DKIM_STAT_OK);
 
 	memset(hdr, '\0', sizeof hdr);
-	status = dkim_getsighdr(dkim, hdr, sizeof hdr, 0, 0);
-	assert(status == DKIM_STAT_OK);
-	assert(strcmp(SIG1, hdr) == 0);
-
-	memset(hdr, '\0', sizeof hdr);
-	status = dkim_getsighdr(dkim, hdr, sizeof hdr, 75,
+	status = dkim_getsighdr(dkim, hdr, sizeof hdr,
 	                        strlen(DKIM_SIGNHEADER) + 2);
 	assert(status == DKIM_STAT_OK);
 	assert(strcmp(SIG2, hdr) == 0);
