@@ -1,10 +1,10 @@
 /*
-**  Copyright (c) 2005-2007 Sendmail, Inc. and its suppliers.
+**  Copyright (c) 2005-2008 Sendmail, Inc. and its suppliers.
 **    All rights reserved.
 */
 
 #ifndef lint
-static char t_test42_c_id[] = "@(#)$Id: t-test42.c,v 1.19 2007/12/12 00:16:25 msk Exp $";
+static char t_test42_c_id[] = "@(#)$Id: t-test42.c,v 1.21 2008/02/29 00:37:22 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -125,7 +125,6 @@ main(int argc, char **argv)
 	int suspicious;
 	DKIM_STAT status;
 	dkim_policy_t pcode;
-	dkim_handling_t hcode;
 	DKIM *dkim;
 	DKIM_LIB *lib;
 	unsigned char hdr[MAXHEADER + 1];
@@ -232,11 +231,9 @@ main(int argc, char **argv)
 
 	testpolicy = 0;
 	suspicious = 0;
-	status = dkim_policy(dkim, &testpolicy, &suspicious, &pcode, &hcode,
-	                     NULL);
+	status = dkim_policy(dkim, &pcode, NULL);
 	assert(status == DKIM_STAT_OK);
 	assert(pcode == DKIM_POLICY_UNKNOWN);
-	assert(hcode == DKIM_HANDLING_PROCESS);
 
 	status = dkim_free(dkim);
 	assert(status == DKIM_STAT_OK);
