@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test45_c_id[] = "@(#)$Id: t-test45.c,v 1.6 2007/06/15 00:22:36 msk Exp $";
+static char t_test45_c_id[] = "@(#)$Id: t-test45.c,v 1.11 2007/07/27 05:39:47 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -123,6 +123,7 @@ tagvalues(void *user, dkim_param_t pcode,
 **  PRESCREEN -- verify the contents of a local_sig structure
 **
 **  Parameters:
+**  	dkim -- DKIM handle
 **  	sigs -- array of DKIM_SIGINFO pointers
 **  	nsigs -- how many sigs there were
 **
@@ -131,11 +132,12 @@ tagvalues(void *user, dkim_param_t pcode,
 */
 
 DKIM_CBSTAT
-prescreen(DKIM_SIGINFO **sigs, int nsigs)
+prescreen(DKIM *dkim, DKIM_SIGINFO **sigs, int nsigs)
 {
 	int c;
 	struct local_sig *ls;
 
+	assert(dkim != NULL);
 	assert(sigs != NULL);
 	assert(nsigs == 2);
 
@@ -310,6 +312,8 @@ main(int argc, char **argv)
 
 	status = dkim_free(dkim);
 	assert(status == DKIM_STAT_OK);
+
+	dkim_close(lib);
 #endif /* ! DKIM_SIGN_RSASHA256 */
 
 	return 0;
