@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test73_c_id[] = "@(#)$Id: t-test73.c,v 1.7 2008/02/29 00:37:22 msk Exp $";
+static char t_test73_c_id[] = "@(#)$Id: t-test73.c,v 1.8 2008/05/22 06:27:24 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -51,6 +51,8 @@ main(int argc, char **argv)
 	dkim_query_t qtype = DKIM_QUERY_FILE;
 	unsigned char hdr[MAXHEADER + 1];
 	unsigned char addr[MAXADDRESS + 1];
+	unsigned char fmt[BUFRSZ];
+	unsigned char opts[BUFRSZ];
 
 	printf("*** simple/simple rsa-sha256 verifying with extra signature spaces and reportinfo (failure)\n");
 
@@ -164,7 +166,13 @@ main(int argc, char **argv)
 	assert(pcode == DKIM_POLICY_ALL);
 
 	/* request report info, verify valid descriptors and address */
-	status = dkim_reportinfo(dkim, sig, &hfd, &bfd, addr, sizeof addr);
+	memset(addr, '\0', sizeof addr);
+	memset(fmt, '\0', sizeof fmt);
+	memset(opts, '\0', sizeof opts);
+	status = dkim_sig_getreportinfo(dkim, sig, &hfd, &bfd,
+	                                addr, sizeof addr,
+	                                fmt, sizeof fmt,
+	                                opts, sizeof opts);
 	assert(status == DKIM_STAT_OK);
 	assert(hfd > 2);
 	assert(bfd > 2);
