@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char t_test87_c_id[] = "@(#)$Id: t-test87.c,v 1.4 2008/02/26 00:45:18 msk Exp $";
+static char t_test87_c_id[] = "@(#)$Id: t-test87.c,v 1.5 2008/05/13 19:56:06 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -71,7 +71,7 @@ main(int argc, char **argv)
 
 	(void) time(&now);
 	len = snprintf(hdr, sizeof hdr, "%s: ", DKIM_SIGNHEADER);
-	snprintf(hdr + len, sizeof hdr - len, SIG2, now + 86400);
+	snprintf(hdr + len, sizeof hdr - len, SIG2, (long) (now + 86400));
 	status = dkim_header(dkim, hdr, strlen(hdr));
 	assert(status == DKIM_STAT_OK);
 
