@@ -4,7 +4,7 @@
 */
 
 #ifndef lint
-static char util_c_id[] = "@(#)$Id: util.c,v 1.22 2008/04/11 23:18:24 msk Exp $";
+static char util_c_id[] = "@(#)$Id: util.c,v 1.24 2008/05/08 00:19:33 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -64,6 +64,7 @@ dkim_collapse(u_char *str)
 	*r = '\0';
 }
 
+#if 0
 /*
 **  DKIM_ADDRCMP -- like strcmp(), except for e-mail addresses (i.e. local-part
 **                  is case-sensitive, while the domain part is not)
@@ -118,6 +119,7 @@ dkim_addrcmp(u_char *s1, u_char *s2)
 
 	return ret;
 }
+#endif /* 0 */
 
 /*
 **  DKIM_HDRLIST -- build up a header list for use in a regexp
@@ -460,6 +462,7 @@ dkim_qp_decode(unsigned char *in, unsigned char *out, int outlen)
 	return q - out;
 }
 
+#ifdef NEED_FAST_STRTOUL
 /*
 **  DKIM_STRTOUL -- convert string to unsigned long
 **
@@ -619,6 +622,7 @@ dkim_strtoull(const char *str, char **endptr, int base)
 	else
 		return value;
 }
+#endif /* NEED_FAST_STRTOUL */
 
 /*
 **  DKIM_CHECK_DNS_REPLY -- see if a DNS reply is truncated or corrupt
