@@ -7,7 +7,7 @@
 #define _UTIL_H_
 
 #ifndef lint
-static char util_h_id[] = "@(#)$Id: util.h,v 1.16 2008/01/31 00:23:31 msk Exp $";
+static char util_h_id[] = "@(#)$Id: util.h,v 1.17 2008/05/08 00:19:33 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -27,9 +27,12 @@ extern bool dkim_hdrlist __P((u_char *, size_t, u_char **, bool));
 extern int dkim_hexchar __P((int c));
 extern void dkim_lowerhdr __P((u_char *));
 extern int dkim_qp_decode __P((u_char *, u_char *, int));
+
+#ifdef NEED_FAST_STRTOUL
 extern unsigned long dkim_strtoul __P((const char *str, char **endptr,
                                        int base));
 extern unsigned long long dkim_strtoull __P((const char *str, char **endptr,
                                              int base));
+#endif /* NEED_FAST_STRTOUL */
 
 #endif /* ! _UTIL_H_ */
