@@ -6,7 +6,7 @@
 #ifdef _FFR_VBR
 
 #ifndef lint
-static char vbr_c_id[] = "@(#)$Id: vbr.c,v 1.8 2007/09/07 00:28:57 msk Exp $";
+static char vbr_c_id[] = "@(#)$Id: vbr.c,v 1.9 2007/10/27 00:52:30 msk Exp $";
 #endif /* !lint */
 
 /* system includes */
@@ -516,6 +516,33 @@ vbr_setcallbackctx(VBR *vbr, void *ctx)
 
 	vbr->vbr_user_context = ctx;
 }
+
+/*
+**  VBR_SETDNSCALLBACK -- set the DNS wait callback
+**
+**  Parameters:
+**  	vbr -- VBR handle, created by vbr_init()
+**  	func -- function to call; should take an opaque context pointer
+**
+**  Return value:
+**  	VBR_STAT_OK -- success
+**  	VBR_STAT_INVALID -- invalid use
+*/
+
+VBR_STAT
+vbr_setdnscallback(VBR *vbr, void (*func)(const void *context))
+{
+	assert(vbr != NULL);
+
+#if USE_ARLIB
+	vbr->vbr_dns_callback = func;
+
+	return VBR_STAT_OK;
+#else /* USE_ARLIB */
+	return VBR_STAT_INVALID;
+#endif /* USE_ARLIB */
+}
+
 #endif /* USE_ARLIB */
 
 /*
